<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>ConfigureOlaIO</name>
    <message>
        <location filename="configureolaio.ui" line="33"/>
        <source>Configure OLA I/O</source>
        <translation>OLA Eingabe/Ausgabe konfigurieren</translation>
    </message>
    <message>
        <location filename="configureolaio.ui" line="40"/>
        <source>Output</source>
        <translation>Ausgang</translation>
    </message>
    <message>
        <location filename="configureolaio.ui" line="45"/>
        <source>OLA Universe</source>
        <translation>OLA Universum</translation>
    </message>
    <message>
        <location filename="configureolaio.ui" line="53"/>
        <source>Run standalone OLA daemon</source>
        <translation>Eigenständigen OLA-Dämon starten</translation>
    </message>
</context>
<context>
    <name>OlaIO</name>
    <message>
        <location filename="olaio.cpp" line="163"/>
        <source>This plugin provides DMX output support for the Open Lighting Architecture (OLA).</source>
        <translation>Dieses Plugin bietet DMX-Output für die Open Lighting Architecture (OLA).</translation>
    </message>
    <message>
        <location filename="olaio.cpp" line="177"/>
        <source>This is the output for OLA universe %1</source>
        <translation>Dies ist der Ausgang für OLA Universum %1</translation>
    </message>
</context>
</TS>
